unit Main;
{==========================================================(SAP / Delphi 2.0)==}
{ Demo der ActiveX (OCX) Komponente:  SAP Logon Control                        }
{ Alles zum Verbindungsaufbau zum SAP R/3 System mit Delphi.                   }
{ Hinweis: Die ActiveX- Komponente WDTLOG.OCX wird von SAP bereitgestellt.     }
{ Das SAP Logon Control ist eine ActiveX Komponente, die die SAP R/3 Anmeldung }
{ zu einem SAP- Datenbankserver aufbaut. Es unterstzt die SAP- Anmeldung so,  }
{ wie diese in der RFC- Bilbliothek vorgesehen ist.                            }
{ Die Komponente vereinfacht es Delphi- Programmieren in Ihrer Client-         }
{ Anwendung einen Verbindungsaufbau zum SAP R/3 System herzustellen.           }
{ Zum Ablauf:                                                                  }
{ ber die Komponente SAP Logon Control wird zuerst ein neues SAP R/3          }
{ Connection object erzeugt (In dieser Demo: 'SAP_ConnectionObject').          }
{ Alle weiteren Aktionen erfolgen mit den Eigenschaften und Methoden dieses    }
{ neuen Objektes.                                                              }
{                                                                              }
{ Typbibliothek      : WDTLOG.OCX  (Siehe hierzu .../RFCSDK/Help/00000001.chm) }
{ Delphi- Komponente : TSAPLogonControl (SAPLogonCtrl_TLB.PAS)                 }
{                                                                              }
{ 1) SAP Logon Control (TSAPLogonControl):                                     }
{ ========================================                                     }
{ Das SAP Logon Control (TSAPLogonControl) stellt folgende Methoden bereit:    }
{ function  TSAPLogonControl.NewConnection: Variant;                           }
{                                      Returns and produces a (new) SAP R/3    }
{                                      Connection Object of type Connection.   }
{                                      =================                       }
{                                   (Typ: Variant = OLE-Automatisierungsobjekt)}
{ procedure TSAPLogonControl.AboutBox;  Dialog: Info ber SAP Logon Control... }
{ procedure TSAPLogonControl.Enable3D; This method makes sure that the dialogs }
{                                      provided have a 3D look and feel.       }
{                                                                              }
{                                                                              }
{ 2) Das (neue) SAP R/3 Connection object:                                     }
{ ========================================                                     }
{ Hinweis: Erzeugt wird das Objekt durch TSAPLogonControl.NewConnection!       }
{ Das neue SAP R/3 Connection Objekt enthlt alle Informationen ber den       }
{ Status und die Parameter fr genau eine Verbindung zu einem SAP-             }
{ Datenbankserver.                                                             }
{                                                                              }
// All Connection object properties can either be set in the design environment
// using a SAP Logon control object or before the method Logon is called on the
// Connection object.
// After a successful logon has taken place, all connection parameters are set
// to read-only, due to the fact that an established connection cannot be changed.
// The property IsConnected displays the actual status of the connection.
// SAP R/3 Connection object: Properties
// =====================================
// ApplicationName   : String;  {Name der Anwendung welche das SAP R/3 Logon Control benutzt.
//                              {Keine Untersttzung in RFC 4.6c! Sonst zur Indentifikation der Verbindung.}
// System            : String;  {Name des SAP R/3 Systems}
// ApplicationServer : String;  {Anwendungs- Server des SAP R/3 Systems}
// SystemNumber      : Longint; {Systemnummer des SAP R/3 Systems}
// MessageServer     : String;  {Message Server of the R/3 System that is doing the load balancing}
// GroupName         : String;  {Name of the group of R/3 Application Servers you want to connect to}
// TraceLevel        : Longint; {Debug On/Off}
// RFCWithDialog     : Longint; {Support RFC with SAPGUI (3.0C or later)}
// Client            : String;  {Client in the R/3 System}
// User              : String;  {User of the R/3 System}
// Password          : String;  {Password of the user. Write-only}
// Language          : String;  {Language you use want to use in R/3}
// IsConnected       : CRfcConnectionStatus; {Aktueller Status des SAP R/3 Connection Objektes. Read-only}
//                                           {Delphi: CRfcConnectionStatus = TOleEnum;}
// SAP R/3 Connection object: Methods
// ==================================
// The (new) SAP R/3 Connection object has the following methods:
// function Logon(hWnd : HWND; Silent: Boolean): Boolean; // Establishes a connection to the R/3 System.
//                                                        // Returns TRUE if successful, FALSE otherwise.
// procedure Logoff;                   // Disconnects a connection from the R/3 object.
// Reconnect;                          // Tries to reestablish a connection to the R/3 System.
// ConnectionObject.LastError;         // Displays a dialog which shows all information about the last RFC Error.
// ConnectionObject.SystemInformation; // Dialog: SAP R/3 Systeminformationen zur aktuellen Verbindung...
{==============================================================================}
interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, OleCtrls, SAPLogonCtrl_TLB, ComCtrls, ExtCtrls, Buttons, Menus,
  wdtlog;

const
{ Dialog: AboutBox - Informationen zum Programm}
    k_Programmname        : string = 'R3_LogOn.EXE';
    k_Versionsnummer      : string = 'v0.01';
    k_Copyright           : string = '2001 / xxxx';
    k_Autor               : string = 'xxxx';
    k_ErstellungsDatum    : string = '10.12.2001';
    k_AenderungsDatum     : string = '11.12.2001';
    k_Betriebssystem      : string = 'WIN 98 / Windows NT 4.0';
    k_Entwicklungsumgebung: string = 'Delphi';
    k_DelphiVersion       : string = '2.0';

type
  TMainForm = class(TForm)
    MainMenu: TMainMenu;
    File_Menu: TMenuItem;
    Datei_Exit_MenuItem: TMenuItem;
    SAP_ConnectionObject_Menu: TMenuItem;
    SAP_ConnectionObject_R3_Logon_MenuItem: TMenuItem;
    SAP_ConnectionObject_R3_LogOff_MenuItem: TMenuItem;
    SAP_Seperator1_MenuItem: TMenuItem;
    SAP_ConnectionObject_SystemInfo_MenuItem: TMenuItem;
    Vorgaben_Menu: TMenuItem;
    Optionen_MenuItem: TMenuItem;
    Hilfe_Menu: TMenuItem;
    Hilfe_About_MenuItem: TMenuItem;
    SpeedPanel: TPanel;
    Datei_Exit_SpeedButton: TSpeedButton;
    SAP_ConnectionObject_R3_Logon_SpeedButton: TSpeedButton;
    SAP_ConnectionObject_R3_LogOff_SpeedButton: TSpeedButton;
    SAP_ConnectionObject_SystemInfo_SpeedButton: TSpeedButton;
    Optionen_SpeedButton: TSpeedButton;
    Hilfe_About_SpeedButton: TSpeedButton;
    SAPLogonControl1_GroupBox: TGroupBox;
    SAPLogonControl1: TSAPLogonControl;
    SAP_ConnectionObject_R3_Logon_BitBtn: TBitBtn;
    SAPLogonControl1_About_BitBtn: TBitBtn;
    SAP_ConnectionObject_GroupBox: TGroupBox;
    SAP_ConnectionObject_System_InfoLabel: TLabel;
    SAP_ConnectionObject_System_Panel: TPanel;
    SAP_ConnectionObject_System_Label: TLabel;
    SAP_ConnectionObject_ApplicationServer_InfoLabel: TLabel;
    SAP_ConnectionObject_ApplicationServer_Panel: TPanel;
    SAP_ConnectionObject_ApplicationServer_Label: TLabel;
    SAP_ConnectionObject_SystemNumber_InfoLabel: TLabel;
    SAP_ConnectionObject_SystemNumber_Panel: TPanel;
    SAP_ConnectionObject_SystemNumber_Label: TLabel;
    SAP_ConnectionObject_MessageServer_InfoLabel: TLabel;
    SAP_ConnectionObject_MessageServer_Panel: TPanel;
    SAP_ConnectionObject_MessageServer_Label: TLabel;
    SAP_ConnectionObject_GroupName_InfoLabel: TLabel;
    SAP_ConnectionObject_GroupName_Panel: TPanel;
    SAP_ConnectionObject_GroupName_Label: TLabel;
    SAP_ConnectionObject_TraceLevel_InfoLabel: TLabel;
    SAP_ConnectionObject_TraceLevel_Panel: TPanel;
    SAP_ConnectionObject_TraceLevel_Label: TLabel;
    SAP_ConnectionObject_RFCWithDialog_InfoLabel: TLabel;
    SAP_ConnectionObject_RFCWithDialog_Panel: TPanel;
    SAP_ConnectionObject_RFCWithDialog_Label: TLabel;
    SAP_ConnectionObject_Client_InfoLabel: TLabel;
    SAP_ConnectionObject_Client_Panel: TPanel;
    SAP_ConnectionObject_Client_Label: TLabel;
    SAP_ConnectionObject_User_InfoLabel: TLabel;
    SAP_ConnectionObject_User_Panel: TPanel;
    SAP_ConnectionObject_User_Label: TLabel;
    SAP_ConnectionObject_Language_InfoLabel: TLabel;
    SAP_ConnectionObject_Language_Panel: TPanel;
    SAP_ConnectionObject_Language_Label: TLabel;
    SAP_ConnectionObject_SystemInfo_BitBtn: TBitBtn;
    SAP_ConnectionObject_R3_LogOff_BitBtn: TBitBtn;
    StatusLine: TStatusBar;
    procedure FormCreate(Sender: TObject);
    procedure ShowHint(Sender: TObject);
    procedure Datei_Exit_MenuItemClick(Sender: TObject);
    procedure SAPLogonControl1Click(Sender: TObject);
    procedure SAPLogonControl1_About_BitBtnClick(Sender: TObject);
    procedure SAP_ConnectionObject_R3_Logon_MenuItemClick(Sender: TObject);
    procedure SAP_ConnectionObject_R3_LogOff_MenuItemClick(Sender: TObject);
    procedure SAP_ConnectionObject_SystemInfo_MenuItemClick(Sender: TObject);
    procedure Optionen_MenuItemClick(Sender: TObject);
    procedure Hilfe_About_MenuItemClick(Sender: TObject);
private
    SAP_ConnectionObject : Variant;   {SAP R/3 Connection Object}
                                      {Delphi: Typ Variant = OLE-Automatisierungsobjekt}

    IsSAP_ConnectionObjectCreate : Boolean; {True = SAP R/3 Connection Object exist}

    procedure WMCLOSE(var Message: TWMCLOSE); message WM_CLOSE; {Close- Ereignis abfangen}

    {Falls noch eine R/3 Verbindung besteht wird diese getrennt (R/3 LogOff)}
    procedure Logoff_SAP_ConnectionObject;

    {Anwendung in R/3 Logon- Zustand setzen}
    {Schalter und die Anzeigefelder fr die Eigenschaften (Properties) des neuen}
    {SAP R/3 Connection Objektes anzeigen. (SAP R/3- Verbindungsaufbau anzeigen)}
    procedure Set_ApplicationStatus_R3_Logon;

   {Anwendung in R/3 LogOff- Zustand zurcksetzen}
    procedure Set_ApplicationStatus_R3_LogOff;

public
    { Public declarations }
end;

var
  MainForm   : TMainForm;

implementation

{$R *.DFM}
uses
 R3LogON,  {Dialog: Verbindung zum SAP R/3 Datenbankserver aufbauen...}
 Optionen, {Dialog: Optionen: Einstellungen fr die Anwendung...}
 About;    {Dialog: Informationen zum Programm...}
{==============================================================(FormCreate)==}
{ Methode: FormCreate                                                        }
{ Standard-Vorgabewete setzen. Die Member erhalten ihre Vorgaben.            }
{============================================================================}
procedure TMainForm.FormCreate(Sender: TObject);
begin
   Application.OnHint          := ShowHint;
// Application.HelpFile        := ExtractFilePath(Application.exeName) + 'MyHelpFile.hlp';

  {Anwendung auf R/3 LogOff- Zustand zurcksetzen}
  {Hinweis: An dieser Stelle ist noch kein SAP_ConnectionObject vorhanden}
  IsSAP_ConnectionObjectCreate := False; {True = SAP R/3 Connection Object exist}

  Set_ApplicationStatus_R3_LogOff;
end;

{================================================================(ShowHint)==}
{ Methode: ShowHint                                                          }
{ ShowHint bestimmt, ob die Schnellhilfe fr die gesamte Anwendung aktiviert }
{ oder nicht aktiviert wird.                                                 }
{============================================================================}
procedure TMainForm.ShowHint(Sender: TObject);
begin
  StatusLine.SimpleText := Application.Hint;
end;

{================================================(Datei_Exit_MenuItemClick)==}
{ Methode: Datei_Exit_MenuItemClick                                          }
{ Beendet diese Anwendung                                                    }
{============================================================================}
procedure TMainForm.Datei_Exit_MenuItemClick(Sender: TObject);
begin
   {Falls noch eine R/3 Verbindung besteht wird diese getrennt (R/3 LogOff)}
   Logoff_SAP_ConnectionObject;
   close;
end;

{=============================(SAP_ConnectionObject_R3_Logon_MenuItemClick)==}
{ Methode: SAP_ConnectionObject_R3_Logon_MenuItemClick                       }
{ Aktivierung des ActiveX (OCX) SAP Logon Control um eine Instanz auf Klasse }
{ TSAPLogonControl erzeugen und wenn mglich eine Verbindung zum SAP R/3     }
{ Datenbankserver ber die neue Klasse SAP_ConnectionObject aufbauen.        }
{============================================================================}
procedure TMainForm.SAP_ConnectionObject_R3_Logon_MenuItemClick(Sender: TObject);
begin
  SAPLogonControl1Click(Sender);

// {Konstruktoraufruf fr den ersten Aufruf}
//  if R3LogonDlg = nil then
//     Application.CreateForm(TR3LogonDlg, R3LogonDlg);
//  R3LogonDlg.ShowModal;
end;

{============================(SAP_ConnectionObject_R3_LogOff_MenuItemClick)==}
{ Methode: SAP_ConnectionObject_R3_LogOff_MenuItemClick                      }
{ Trennt die Verbindung zu einem SAP R/3- Datenbankserver (SAP Logoff)       }
{============================================================================}
procedure TMainForm.SAP_ConnectionObject_R3_LogOff_MenuItemClick(Sender: TObject);
begin
   {Falls noch eine R/3 Verbindung besteht wird diese getrennt (R/3 LogOff)}
   Logoff_SAP_ConnectionObject;
end;

{===========================(SAP_ConnectionObject_SystemInfo_MenuItemClick)==}
{ Methode: SAP_ConnectionObject_SystemInfo_MenuItemClick                     }
{ Dialog: SAP R/3 Systeminformationen zur aktuellen Verbindung...            }
{============================================================================}
procedure TMainForm.SAP_ConnectionObject_SystemInfo_MenuItemClick(Sender: TObject);
begin
  SAP_ConnectionObject.SystemInformation;
end;

{==================================================(Optionen_MenuItemClick)==}
{ Methode: Optionen_MenuItemClick                                            }
{ Dialog: Optionen: Einstellungen fr die Anwendung...                       }
{============================================================================}
procedure TMainForm.Optionen_MenuItemClick(Sender: TObject);
begin
 {Konstruktoraufruf fr den ersten Aufruf}
  if OptionenDlg = nil then
     Application.CreateForm(TOptionenDlg, OptionenDlg);
  OptionenDlg.ShowModal;
end;

{===============================================(Hilfe_About_MenuItemClick)==}
{ Methode: Hilfe_About_MenuItemClick                                         }
{============================================================================}
procedure TMainForm.Hilfe_About_MenuItemClick(Sender: TObject);
begin
 {Konstruktoraufruf fr den ersten Aufruf}
  if AboutBox = nil then Application.CreateForm(TAboutBox, AboutBox);
  AboutBox.EingabeWerte(k_Programmname,
                        k_Versionsnummer,
                        k_Copyright,
                        k_Autor,
                        k_ErstellungsDatum,
                        k_AenderungsDatum,
                        k_Betriebssystem,
                        k_Entwicklungsumgebung,
                        k_DelphiVersion);
  AboutBox.ShowModal;
end;

{===================================================(SAPLogonControl1Click)==}
{ Methode: SAPLogonControl1Click                                             }
{ Einloggen zu einem SAP- Datenbankserver (SAP Logon)...                     }
{                                                                            }
{ Hinweis zur Methode: SAP_ConnectionObject.LogOn                            }
{ function LogOn(ParentWindow : HWND,  Silent : Boolean): Boolean;           }
{ Set the Silent parameter to FALSE if you want the system to display a      }
{ Logon dialog.                                                              }
{ If not, set all parameters in advance: the system will log the user on     }
{ silently.                                                                  }
{ If you set Silent to TRUE and omit logon parameter values, the method      }
{ always fails.                                                              }
{ If the method succeeds, it returns TRUE, otherwise FALSE.                  }
{ When FALSE, use the IsConnected property to determine the type of logon    }
{ failure.                                                                   }
{============================================================================}
procedure TMainForm.SAPLogonControl1Click(Sender: TObject);
var RfcConnectionStatus_Nr   : Integer;
    RfcConnectionStatus_Text : String;
begin
 {Rckgabe und Erzeugung eines neuen SAP R/3 Connection Objektes}
 {vom Typ Connection (Delphi: SAP_ConnectionObject: Variant; = OLE-Automatisierungsobjekt)}
 SAP_ConnectionObject         := SAPLogOnControl1.NewConnection;

 IsSAP_ConnectionObjectCreate := True; {True = SAP R/3 Connection Object exist}

 {Anmeldung zum SAP R/3 System ber die Anzeige des Logon- Dialogfensters}
 {Hinweis: Silent = False}
 if SAP_ConnectionObject.LogOn(0, False) = True then
  begin
   {Anwendung in R/3 Logon- Zustand setzen}
   {Schalter und die Anzeigefelder fr die Eigenschaften (Properties) des neuen}
   {SAP R/3 Connection Objektes anzeigen. (SAP R/3- Verbindungsaufbau anzeigen)}
   Set_ApplicationStatus_R3_Logon;

   showmessage('SAP R/3 Logged On.');
  end
 else
  begin {SAP R/3 - Logon ist fehlgeschlagen!}

    {Anwendung in R/3 LogOff- Zustand zurcksetzen}
    Set_ApplicationStatus_R3_LogOff;

    RfcConnectionStatus_Nr :=  SAP_ConnectionObject.IsConnected;

    if RfcConnectionStatus_Nr = tloRfcNotConnected then    {tloRfcNotConnected = 0}
       RfcConnectionStatus_Text :=  'Es besteht keine Verbindung zwischen dieser Anwendung und dem SAP R/3 System.' + #13#10+
                                    'Das SAP R/3- System bentigt eine Anmeldung. Der Benutzer ist noch nicht mit SAP R/3 -' + #13#10+
                                    'System angemeldet oder er hat sich zwischenzeitlich abgemeldet (ausgeloggt).';

    if RfcConnectionStatus_Nr = tloRfcConnected then       {tloRfcConnected = 1}
       RfcConnectionStatus_Text :=  'Die Verbindung zwischen dieser Anwendung und dem SAP R/3 System besteht bereits.';

    if RfcConnectionStatus_Nr = tloRfcConnectCancel then   {tloRfcConnectCancel= 2}
       RfcConnectionStatus_Text :=  'Es besteht keine Verbindung zwischen dieser Anwendung und dem SAP R/3 System.' + #13#10+
                                    'Das SAP R/3- System bentigt eine Anmeldung. Sie haben beim SAP Logon den Abbruch-' + #13#10+
                                    'Schalter gedrckt und somit die SAP R/3- Anmeldung abgebrochen.';

    if RfcConnectionStatus_Nr = tloRfcConnectParameterMissing then  {tloRfcConnectParameterMissing = 4}
       RfcConnectionStatus_Text :=  'Es besteht keine Verbindung zwischen dieser Anwendung und dem SAP R/3 System.' + #13#10+
                                    'A silent logon was attempted with connection parameters.';


    {Dialog: SAP_ConnectionObject.LastError;  tloRfcConnectFailed= 8}
    {Hinweis: Wird an dieser Stelle bei Fehler Nr. 8 automatisch erzeugt und angezeigt!}
   // if RfcConnectionStatus_Nr = tloRfcConnectFailed then     {tloRfcConnectFailed = 8}
   //                             SAP_ConnectionObject.LastError;

    if RfcConnectionStatus_Nr <> tloRfcConnectFailed then
     Application.MessageBox(pChar('' + #13#10 +
                                 'Ihr Versuch sich in das SAP R/3 System einzuloggen ist fehlgeschlagen!' + #13#10+
                                 '' + #13#10 +
                                 'Statusmeldung Nr.: ' + IntToStr(RfcConnectionStatus_Nr)+ #13#10+
                                 '' + #13#10 +
                                  RfcConnectionStatus_Text),
                                 'SAP R/3 Anmeldung fehlgeschlagen!', MB_ICONINFORMATION);
   end;
end;

{=================================================================(WM_CLOSE)=}
{ Nachrichten-Methode : WMCLOSE                                              }
{ Schlieen abfangen.                                                        }
{============================================================================}
procedure TMainForm.WMCLOSE(var Message: TWMCLOSE);
begin
   Message.Result := 1;

  {Falls noch eine R/3 Verbindung besteht wird diese getrennt (R/3 LogOff)}
  Logoff_SAP_ConnectionObject;
  close;
end;

{=======================================(SAPLogonControl_About_BitBtnClick)==}
{ Methode: SAPLogonControl_About_BitBtnClick                                 }
{ Info zum SAP Automation ActiveX (OCX) Control:  SAP Logon Control          }
{ Delphi- Komponente : TSAPLogonControl (SAPLogonCtrl_TLB.PAS)               }
{ Typbibliothek      : WDTLOG.OCX                                            }
{============================================================================}
procedure TMainForm.SAPLogonControl1_About_BitBtnClick(Sender: TObject);
begin
  SAPLogOnControl1.AboutBox;
end;

{=============================================(Logoff_SAP_ConnectionObject)==}
{ Methode: Logoff_SAP_ConnectionObject                                       }
{ Falls noch eine R/3 Verbindung besteht wird diese getrennt (R/3 LogOff)    }
{============================================================================}
procedure TMainForm.Logoff_SAP_ConnectionObject;
begin
 if IsSAP_ConnectionObjectCreate = True then {True = SAP R/3 Connection Object exist}
   begin
    if SAP_ConnectionObject.IsConnected = tloRfcConnected then
       begin
         SAP_ConnectionObject.Logoff; {Disconnects an established RFC connection}

        {Anwendung auf R/3 LogOff- Zustand zurcksetzen}
         Set_ApplicationStatus_R3_LogOff;

         ShowMessage('SAP R/3 System LogOff...');
       end;
   end;
end;

{==========================================(Set_ApplicationStatus_R3_Logon)==}
{ Methode: Set_ApplicationStatus_R3_Logon                                    }
{ Anwendung in R/3 Logon- Zustand setzen.                                    }
{ Anzeige der Eigenschaften (Properties) des neuen R/3 Connection Objektes.  }
{ Das durch TSAPLogonControl.NewConnection erzeugte neue SAP R/3 Connection- }
{ Objekt enthlt alle Informationen ber den Status und die Parameter fr    }
{ genau eine Verbindung zu einem SAP R/3 - Datenbankserver.                  }
{============================================================================}
procedure TMainForm.Set_ApplicationStatus_R3_Logon;
begin
 {Labels for show the Connection object Properties:}

 {Name der Anwendung welche das SAP R/3 Logon Control benutzt.}
 {Wird zur Indentifikation der Verbindung genutzt.}
 {Hinweis: Wird in der RFC- Version 4.6c nicht untersttzt!}
// xxxx_Label.Caption := SAP_ConnectionObject.ApplicationName;

 {Name des SAP R/3 Systems}
 SAP_ConnectionObject_System_Label.Caption := SAP_ConnectionObject.System;

 {Anwendungs- Server des SAP R/3 Systems}
 SAP_ConnectionObject_ApplicationServer_Label.Caption := SAP_ConnectionObject.ApplicationServer;

 {Systemnummer des SAP R/3 Systems}
 SAP_ConnectionObject_SystemNumber_Label.Caption := IntToStr(SAP_ConnectionObject.SystemNumber);

 {Message Server of the R/3 System that is doing the load balancing}
 SAP_ConnectionObject_MessageServer_Label.Caption := SAP_ConnectionObject.MessageServer;

 {Name of the group of R/3 Application Servers you want to connect to}
 SAP_ConnectionObject_GroupName_Label.Caption := SAP_ConnectionObject.GroupName;

 {Debug On/Off}
 if SAP_ConnectionObject.TraceLevel = 0 then
    SAP_ConnectionObject_TraceLevel_Label.Caption := 'Debug On'
 else
    SAP_ConnectionObject_TraceLevel_Label.Caption := 'Debug Off';

 {Support RFC with SAPGUI (3.0C or later)}
 if SAP_ConnectionObject.RFCWithDialog = 0 then
    SAP_ConnectionObject_RFCWithDialog_Label.Caption := 'Support RFC with SAPGUI'
 else
    SAP_ConnectionObject_RFCWithDialog_Label.Caption := 'No support';

 {Client in the R/3 System}
 SAP_ConnectionObject_Client_Label.Caption := SAP_ConnectionObject.Client;

 {User of the R/3 System}
 SAP_ConnectionObject_User_Label.Caption := SAP_ConnectionObject.User;

 {Password of the user. Write-only}
// yyyy_Label.Caption := SAP_ConnectionObject.Password;

 {Language you use want to use in R/3}
 SAP_ConnectionObject_Language_Label.Caption := SAP_ConnectionObject.Language;

  {SAP R/3 Logon...}
  SAP_ConnectionObject_R3_Logon_MenuItem.Enabled      := False;
  SAP_ConnectionObject_R3_Logon_SpeedButton.Enabled   := False;
  SAP_ConnectionObject_R3_Logon_BitBtn.Enabled        := False;

  {SAP R/3 LogOff}
  SAP_ConnectionObject_R3_LogOff_MenuItem.Enabled     := True;
  SAP_ConnectionObject_R3_LogOff_SpeedButton.Enabled  := True;
  SAP_ConnectionObject_R3_LogOff_BitBtn.Enabled       := True;

 {Dialog with all system information about the connected R/3 System...}
  SAP_ConnectionObject_SystemInfo_MenuItem.Enabled    := True;
  SAP_ConnectionObject_SystemInfo_SpeedButton.Enabled := True;
  SAP_ConnectionObject_SystemInfo_BitBtn.Enabled      := True;
 end;

{=========================================(Set_ApplicationStatus_R3_LogOff)==}
{ Methode: Set_ApplicationStatus_R3_LogOff                                   }
{ Anwendung auf R/3 LogOff- Zustand zurcksetzen.                            }
{ Schalter und die Anzeigefelder fr die Eigenschaften (Properties) auf      }
{ R/3 LogOff Zustand zurcksetzen.                                           }
{============================================================================}
procedure TMainForm.Set_ApplicationStatus_R3_LogOff;
begin
 {Labels for show the Connection object Properties:}
 // ApplicationName_Label.Caption                      := '---';
  SAP_ConnectionObject_System_Label.Caption            := '---';
  SAP_ConnectionObject_ApplicationServer_Label.Caption := '---';
  SAP_ConnectionObject_SystemNumber_Label.Caption      := '---';
  SAP_ConnectionObject_MessageServer_Label.Caption     := '---';
  SAP_ConnectionObject_GroupName_Label.Caption         := '---';
  SAP_ConnectionObject_TraceLevel_Label.Caption        := '---';
  SAP_ConnectionObject_RFCWithDialog_Label.Caption     := '---';
  SAP_ConnectionObject_Client_Label.Caption            := '---';
  SAP_ConnectionObject_User_Label.Caption              := '---';
 // Password_Label.Caption                             := '---';
  SAP_ConnectionObject_Language_Label.Caption          := '---';

  {SAP R/3 Logon...}
  SAP_ConnectionObject_R3_Logon_MenuItem.Enabled       := True;
  SAP_ConnectionObject_R3_Logon_SpeedButton.Enabled    := True;
  SAP_ConnectionObject_R3_Logon_BitBtn.Enabled         := True;

  {SAP R/3 LogOff}
  SAP_ConnectionObject_R3_LogOff_MenuItem.Enabled      := False;
  SAP_ConnectionObject_R3_LogOff_SpeedButton.Enabled   := False;
  SAP_ConnectionObject_R3_LogOff_BitBtn.Enabled        := False;

 {Dialog with all system information about the connected R/3 System...}
  SAP_ConnectionObject_SystemInfo_MenuItem.Enabled     := False;
  SAP_ConnectionObject_SystemInfo_SpeedButton.Enabled  := False;
  SAP_ConnectionObject_SystemInfo_BitBtn.Enabled       := False;
 end;

end.
